"""Generate fourier components for fourier seasonality"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/model_helpers/00_fourier_components.ipynb.

# %% auto 0
__all__ = ['generate_fourier_components']

# %% ../../nbs/model_helpers/00_fourier_components.ipynb 3
import pandas as pd
import numpy as np

# %% ../../nbs/model_helpers/00_fourier_components.ipynb 6
def generate_fourier_components(
  N_samples: int, # Number of samples
  N_components: int = 3, # Half the number of Fourier components
  period: int = 52 # Yearly period of weekly data
) -> pd.DataFrame: # Dataframe with fourier components
    "Generate Fourier components for a given number of samples and components."
    t = np.linspace(0, N_samples, N_samples)
    fourier_components = pd.DataFrame()
    for i in range(N_components):
        fourier_components[f'fourier_sin_{i}'] = np.sin(2 * np.pi * (i + 1) * t / period)
    for i in range(N_components):
        fourier_components[f'fourier_cos_{i}'] = np.cos(2 * np.pi * (i + 1) * t / period)
    return fourier_components
  
